==> tencentcloud-sdk-java-3.0.93-sources.jar: com/tencentcloudapi/cds/v20180420/models/DescribeDbauditInstancesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cds.v20180420.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDbauditInstancesResponse  extends AbstractModel{

    /**
    * 总实例数
    */
    @SerializedName("TotalCount")
    @Expose
    private Integer TotalCount;

    /**
    * 数据安全审计实例信息列表
    */
    @SerializedName("CdsAuditInstanceSet")
    @Expose
    private CdsAuditInstance [] CdsAuditInstanceSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * 获取总实例数
     * @return TotalCount 总实例数
     */
    public Integer getTotalCount() {
        return this.TotalCount;
    }

    /**
     * 设置总实例数
     * @param TotalCount 总实例数
     */
    public void setTotalCount(Integer TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * 获取数据安全审计实例信息列表
     * @return CdsAuditInstanceSet 数据安全审计实例信息列表
     */
    public CdsAuditInstance [] getCdsAuditInstanceSet() {
        return this.CdsAuditInstanceSet;
    }

    /**
     * 设置数据安全审计实例信息列表
     * @param CdsAuditInstanceSet 数据安全审计实例信息列表
     */
    public void setCdsAuditInstanceSet(CdsAuditInstance [] CdsAuditInstanceSet) {
        this.CdsAuditInstanceSet = CdsAuditInstanceSet;
    }

    /**
     * 获取唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * 设置唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "CdsAuditInstanceSet.", this.CdsAuditInstanceSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/cds/v20180420/models/DescribeDbauditInstancesResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cds.v20180420.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeDbauditInstancesResponse extends AbstractModel{

    /**
    * 总实例数
    */
    @SerializedName("TotalCount")
    @Expose
    private Long TotalCount;

    /**
    * 数据安全审计实例信息列表
    */
    @SerializedName("CdsAuditInstanceSet")
    @Expose
    private CdsAuditInstance [] CdsAuditInstanceSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 总实例数 
     * @return TotalCount 总实例数
     */
    public Long getTotalCount() {
        return this.TotalCount;
    }

    /**
     * Set 总实例数
     * @param TotalCount 总实例数
     */
    public void setTotalCount(Long TotalCount) {
        this.TotalCount = TotalCount;
    }

    /**
     * Get 数据安全审计实例信息列表 
     * @return CdsAuditInstanceSet 数据安全审计实例信息列表
     */
    public CdsAuditInstance [] getCdsAuditInstanceSet() {
        return this.CdsAuditInstanceSet;
    }

    /**
     * Set 数据安全审计实例信息列表
     * @param CdsAuditInstanceSet 数据安全审计实例信息列表
     */
    public void setCdsAuditInstanceSet(CdsAuditInstance [] CdsAuditInstanceSet) {
        this.CdsAuditInstanceSet = CdsAuditInstanceSet;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TotalCount", this.TotalCount);
        this.setParamArrayObj(map, prefix + "CdsAuditInstanceSet.", this.CdsAuditInstanceSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
